@@ -59,7 +59,7 @@ class Dispatcher:
         self.initialized = loop.create_future()
         family = socket.AF_INET6 if self.ip_type is types.AAAA else socket.AF_INET
         _transport, self.protocol = await loop.create_datagram_endpoint(
-                CallbackProtocol, family=family, reuse_port=True, local_addr=self.local_addr)
+                CallbackProtocol, family=family, local_addr=self.local_addr)
         self.initialized.set_result(None)
 
     async def send(self, req, addr, timeout):
